00:39 alati joined
alati greetings all.. hope all is well 00:41
beginning a new journey to use raku for most of my tasks 00:42
instead of googling and searching about I thought to come to the irc and ask if anyone might already have a project regarding gherkin/bdd and raku incorporation? 00:43
I did come across raku++ for client side raku development. looks like a great project 00:44
not that those 2 things are related but I'm just going across anything raku is currently involved with 00:45
[Coke] you may want #raku instead of #raku-dev 00:46
alati aha... Thanks Coke
long ago I think my nick was myhrlin when we last chatted 00:47
give or take 20 years or so
02:45 alati left 06:01 djinni`_ joined, rnddim joined 06:06 ShimmerFairy left, rnddim is now known as ShimmerFairy 06:08 djinni` left, jjatria left 06:14 jjatria joined 06:15 kjp left 06:19 kjp joined
Geth rakudo/lizmat-69: ed3c29ba2a | (Elizabeth Mattijsen)++ | src/Raku/ast/expressions.rakumod
RakuAST: optimize ::Infix.IMPL-APPLY-SINK-TO-OPERANDS

In this relatively hot piece of code, replace for loops by native nqp::while and use nqp::atpos instead of postcircumfix []. For reference, an nqp::while loop + nqp::atpos is about 2x as fast as a for loop in nqp. That's because the iterator overhead is pretty big in nqp. And using nqp ops also creates smaller bytecode so more chance of inlining.
11:08
rakudo: lizmat++ created pull request #6840:
RakuAST: optimize ::Infix.IMPL-APPLY-SINK-TO-OPERANDS
11:16 finanalyst joined
Geth rakudo/lizmat-70: e9c52759a4 | (Elizabeth Mattijsen)++ | src/Raku/ast/expressions.rakumod
RakuAST: optimize ::Assignment.IMPL-APPLY-SINK-TO-OPERANDS

In this relatively hot piece of code, replace for loops by native nqp::while and use nqp::atpos instead of postcircumfix []. For reference, an nqp::while loop + nqp::atpos is about 2x as fast as a for loop in nqp. That's because the iterator overhead is pretty big in nqp. And using nqp ops also creates smaller bytecode so more chance of inlining
11:26
rakudo: lizmat++ created pull request #6841:
RakuAST: optimize ::Assignment.IMPL-APPLY-SINK-TO-OPERANDS
11:27
rakudo/lizmat-71: 1dc6a0f009 | (Elizabeth Mattijsen)++ | src/Raku/ast/resolver.rakumod
RakuAST: streamline ::Resolver::(EVAL|Compile)

Specifically the .current-scope and .outer.scope methods, as these are pretty hot during compilation, and use atpos(..,i) vs ...[i] is about 2x as fast.
12:41
rakudo: lizmat++ created pull request #6842:
RakuAST: streamline ::Resolver::(EVAL|Compile)
12:42
rakudo/lizmat-72: c3a9913652 | (Elizabeth Mattijsen)++ | src/Raku/ast/resolver.rakumod
RakuAST: streamline ::Resolver::(EVAL|Compile).find-scope-property

Another hot method during compilation, rewritten to use atpos and no return statements.
13:17
rakudo: lizmat++ created pull request #6843:
RakuAST: streamline ::Resolver::(EVAL|Compile).find-scope-property
[Coke] blin clear through 3388d045c2 14:40
linkable6 (2026-10-10) github.com/rakudo/rakudo/commit/3388d045c2 Bump NQP to fix an issue with spesh, ugexe++
lizmat c: HEAD my @k[*;3]; dd @k[3] 22:38
committable6 lizmat, ¦HEAD(3388d04): «Array␤»
23:19 finanalyst left